==> aliyun-python-sdk-ocr-1.0.13.tar.gz: aliyun-python-sdk-ocr-1.0.13/aliyunsdkocr/request/v20191230/RecognizeCharacterRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkocr.endpoint import endpoint_data

class RecognizeCharacterRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeCharacter','ocr')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_MinHeight(self):
		return self.get_body_params().get('MinHeight')

	def set_MinHeight(self,MinHeight):
		self.add_body_params('MinHeight', MinHeight)

	def get_OutputProbability(self):
		return self.get_body_params().get('OutputProbability')

	def set_OutputProbability(self,OutputProbability):
		self.add_body_params('OutputProbability', OutputProbability)

	def get_ImageURL(self):
		return self.get_body_params().get('ImageURL')

	def set_ImageURL(self,ImageURL):
		self.add_body_params('ImageURL', ImageURL)

==> aliyun-python-sdk-ocr-1.0.21.tar.gz: aliyun-python-sdk-ocr-1.0.21/aliyunsdkocr/request/v20191230/RecognizeCharacterRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkocr.endpoint import endpoint_data

class RecognizeCharacterRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeCharacter','ocr')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MinHeight(self): # Integer
		return self.get_body_params().get('MinHeight')

	def set_MinHeight(self, MinHeight):  # Integer
		self.add_body_params('MinHeight', MinHeight)
	def get_OutputProbability(self): # Boolean
		return self.get_body_params().get('OutputProbability')

	def set_OutputProbability(self, OutputProbability):  # Boolean
		self.add_body_params('OutputProbability', OutputProbability)
	def get_ImageURL(self): # String
		return self.get_body_params().get('ImageURL')

	def set_ImageURL(self, ImageURL):  # String
		self.add_body_params('ImageURL', ImageURL)
